==> allure-0.11.0.0-306.1-loong64.pkg.tar.zst: usr/share/haskell/register/allure.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 Allure
version:              0.11.0.0
visibility:           public
id:                   Allure-0.11.0.0-2vBPtysMIel2Ka4mHyDOQI
key:                  Allure-0.11.0.0-2vBPtysMIel2Ka4mHyDOQI
license:              AGPL-3.0-or-later
maintainer:           Mikolaj Konarski <mikolaj.konarski@funktory.com>
author:               Andres Loeh, Mikolaj Konarski and others
homepage:             http://allureofthestars.com
synopsis:             Near-future Sci-Fi roguelike and tactical squad combat game
description:
    Allure of the Stars is a near-future Sci-Fi roguelike
    and tactical squad combat game. Binaries and the game manual
    are available at the homepage. You can also try the game out
    in the browser at <http://allureofthestars.com/play>.

    Not a single image in this game. You have to imagine everything
    yourself, like with a book (a grown-up book, without pictures).
    Once you learn to imagine things, though, you can keep exploring
    and mastering the world and making up stories for a long time.

    The game is written in Haskell using the LambdaHack roguelike
    game engine <http://hackage.haskell.org/package/LambdaHack>.
    Please see the changelog file for recent improvements
    and the issue tracker for short-term plans. Long term goals
    are high replayability and auto-balancing through procedural
    content generation and persistent content modification
    based on player behaviour. Contributions are welcome.

    This is a workaround .cabal file, flattened to eliminate
    internal libraries until generating haddocks for them
    is fixed. The original .cabal file is in .cabal.bkp file.

category:             Game
abi:                  9144935ee339e402a5d5b7de976e9904
exposed:              True
exposed-modules:
    Client.UI.Content.Input Client.UI.Content.Screen Content.CaveKind
    Content.FactionKind Content.ItemKind Content.ItemKindActor
    Content.ItemKindBlast Content.ItemKindEmbed Content.ItemKindOrgan
    Content.ItemKindTemporary Content.ModeKind Content.PlaceKind
    Content.RuleKind Content.TileKind
    Implementation.MonadClientImplementation
    Implementation.MonadServerImplementation TieKnot

hidden-modules:       Paths_Allure
import-dirs:          /usr/lib/ghc-9.6.6/site-local/Allure-0.11.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/Allure-0.11.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/Allure-0.11.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/allure
hs-libraries:         HSAllure-0.11.0.0-2vBPtysMIel2Ka4mHyDOQI
depends:
    LambdaHack-0.11.0.1-54pENrk4pj557IS0nd52ei
    async-2.2.5-1Z88VuXAsSjFYCStMD3XFv base-4.18.2.1
    enummapset-0.7.3.0-2dh8JkjpSa6IrHg1zYWgj5
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz filepath-1.4.300.1
    ghc-compact-0.1.0.0 hsini-0.5.2.2-D3LW6pzHGpNHdW5vy9HgY6
    optparse-applicative-0.18.1.0-AbA9pm273O8LTotNJ1t1CE
    primitive-0.9.1.0-FoKmvnfKMVpLetWIAmWZ
    splitmix-0.1.3-9CESEz75Upa7nQgfltLRDI template-haskell-2.20.0.0
    text-2.0.2 th-lift-instances-0.1.20-DkQ3pSoBs6v1kedDErI2tH
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/allure/html/Allure.haddock
haddock-html:         /usr/share/doc/allure/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> allure-0.11.0.0-307-loong64.pkg.tar.zst: usr/share/haskell/register/allure.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 Allure
version:              0.11.0.0
visibility:           public
id:                   Allure-0.11.0.0-37oIsWp0C2I2NcKhp5LBLD
key:                  Allure-0.11.0.0-37oIsWp0C2I2NcKhp5LBLD
license:              AGPL-3.0-or-later
maintainer:           Mikolaj Konarski <mikolaj.konarski@funktory.com>
author:               Andres Loeh, Mikolaj Konarski and others
homepage:             http://allureofthestars.com
synopsis:             Near-future Sci-Fi roguelike and tactical squad combat game
description:
    Allure of the Stars is a near-future Sci-Fi roguelike
    and tactical squad combat game. Binaries and the game manual
    are available at the homepage. You can also try the game out
    in the browser at <http://allureofthestars.com/play>.

    Not a single image in this game. You have to imagine everything
    yourself, like with a book (a grown-up book, without pictures).
    Once you learn to imagine things, though, you can keep exploring
    and mastering the world and making up stories for a long time.

    The game is written in Haskell using the LambdaHack roguelike
    game engine <http://hackage.haskell.org/package/LambdaHack>.
    Please see the changelog file for recent improvements
    and the issue tracker for short-term plans. Long term goals
    are high replayability and auto-balancing through procedural
    content generation and persistent content modification
    based on player behaviour. Contributions are welcome.

    This is a workaround .cabal file, flattened to eliminate
    internal libraries until generating haddocks for them
    is fixed. The original .cabal file is in .cabal.bkp file.

category:             Game
abi:                  afa851b5782cf92dbe1cef569ecf5603
exposed:              True
exposed-modules:
    Client.UI.Content.Input Client.UI.Content.Screen Content.CaveKind
    Content.FactionKind Content.ItemKind Content.ItemKindActor
    Content.ItemKindBlast Content.ItemKindEmbed Content.ItemKindOrgan
    Content.ItemKindTemporary Content.ModeKind Content.PlaceKind
    Content.RuleKind Content.TileKind
    Implementation.MonadClientImplementation
    Implementation.MonadServerImplementation TieKnot

hidden-modules:       Paths_Allure
import-dirs:          /usr/lib/ghc-9.6.6/site-local/Allure-0.11.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/Allure-0.11.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/Allure-0.11.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/allure
hs-libraries:         HSAllure-0.11.0.0-37oIsWp0C2I2NcKhp5LBLD
depends:
    LambdaHack-0.11.0.1-9rewoqCrozr5pAcO30BAxI
    async-2.2.5-6z3frWRfGJJLLgOv3gEskc base-4.18.2.1
    enummapset-0.7.3.0-9IIdu7sihJJI8JszAnk4X4
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz filepath-1.4.300.1
    ghc-compact-0.1.0.0 hsini-0.5.2.2-JG1Z19ujd4q6tTQVRHgP5w
    optparse-applicative-0.18.1.0-BnGHnrTdK6d4c7MmJxSY0G
    primitive-0.9.1.0-Gw11eCcStSPCrwBXmVDBSi
    splitmix-0.1.3-90QrqABg5SpKi5FtNwnDR8 template-haskell-2.20.0.0
    text-2.0.2 th-lift-instances-0.1.20-LTMKJZnS7WY2o6yRFgu9GC
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/allure/html/Allure.haddock
haddock-html:         /usr/share/doc/allure/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
